@@ -14,8 +14,7 @@ module Browser
         .map {|string| string.squeeze(" ").strip }
         .map {|part| new(part) }
         .reject {|al| al.quality.zero? }
-        .sort_by(&:quality)
-        .reverse
+        .sort_by.with_index {|al, idx| [-al.quality, idx] }
     end
 
     attr_reader :part
@@ -35,28 +34,26 @@ module Browser
     def code
       @code ||= begin
         code = part[/\A([^-;]+)/, 1]
-        code.downcase if code
+        code&.downcase
       end
     end
 
     def region
       @region ||= begin
         region = part[/\A(?:.*?)-([^;-]+)/, 1]
-        region.upcase if region
+        region&.upcase
       end
     end
 
     def quality
       @quality ||= begin
         Float(quality_value || 1.0)
-      rescue ArgumentError
-        0.1
+                   rescue ArgumentError
+                     0.1
       end
     end
 
-    private
-
-    def quality_value
+    private def quality_value
       qvalue = part[/;q=([\d.]+)/, 1]
       qvalue = qvalue =~ /\A0\.0?\z/ ? "0.0" : qvalue
       qvalue = qvalue.gsub(/\.+/, ".") if qvalue
