@@ -50,11 +50,6 @@ module Browser
       @device ||= Device.new(ua)
     end
 
-    # Return true if browser is modern (Webkit, Firefox 17+, IE9+, Opera 12+).
-    def modern?
-      Browser.modern_rules.any? {|rule| rule === self } # rubocop:disable Metrics/LineLength, Style/CaseEquality
-    end
-
     # Detect if browser is Microsoft Internet Explorer.
     def ie?(expected_version = nil)
       InternetExplorer.new(ua).match? &&
@@ -78,6 +73,18 @@ module Browser
       "0"
     end
 
+    # Detect if browser is Instagram.
+    def instagram?(expected_version = nil)
+      Instagram.new(ua).match? &&
+        detect_version?(full_version, expected_version)
+    end
+
+    # Detect if browser is Snapchat.
+    def snapchat?(expected_version = nil)
+      Snapchat.new(ua).match? &&
+        detect_version?(full_version, expected_version)
+    end
+
     # Detect if browser if Facebook.
     def facebook?(expected_version = nil)
       Facebook.new(ua).match? &&
@@ -93,7 +100,7 @@ module Browser
     # Detect if browser is WebKit-based.
     def webkit?(expected_version = nil)
       ua =~ /AppleWebKit/i &&
-        !edge? &&
+        (!edge? || Edge.new(ua).chrome_based?) &&
         detect_version?(webkit_full_version, expected_version)
     end
 
@@ -137,10 +144,16 @@ module Browser
       Opera.new(ua).match? && detect_version?(full_version, expected_version)
     end
 
+    # Detect if browser is Sputnik.
+    def sputnik?(expected_version = nil)
+      Sputnik.new(ua).match? && detect_version?(full_version, expected_version)
+    end
+
     # Detect if browser is Yandex.
     def yandex?(expected_version = nil)
-      ua =~ /YaBrowser/ && detect_version?(full_version, expected_version)
+      Yandex.new(ua).match? && detect_version?(full_version, expected_version)
     end
+    alias_method :yandex_browser?, :yandex?
 
     # Detect if browser is UCBrowser.
     def uc_browser?(expected_version = nil)
@@ -174,8 +187,18 @@ module Browser
       ua =~ /Opera Mini/ && detect_version?(full_version, expected_version)
     end
 
+    # Detect if browser is DuckDuckGo.
+    def duck_duck_go?(expected_version = nil)
+      ua =~ /DuckDuckGo/ && detect_version?(full_version, expected_version)
+    end
+
+    # Detect if browser is Samsung.
+    def samsung_browser?(expected_version = nil)
+      ua =~ /SamsungBrowser/ && detect_version?(full_version, expected_version)
+    end
+
     def webkit_full_version
-      ua[%r[AppleWebKit/([\d.]+)], 1] || "0.0"
+      ua[%r{AppleWebKit/([\d.]+)}, 1] || "0.0"
     end
 
     def known?
