@@ -11,8 +11,8 @@ module Browser
     end
 
     def full_version
-      ua[%r[BlackBerry[\da-z]+/([\d.]+)], 1] ||
-        ua[%r[Version/([\d.]+)], 1] ||
+      ua[%r{BlackBerry[\da-z]+/([\d.]+)}, 1] ||
+        ua[%r{Version/([\d.]+)}, 1] ||
         "0.0"
     end
 
