@@ -16,8 +16,8 @@ module Browser
     end
 
     def full_version
-      ua[%r[(?:QuickTime)/([\d.]+)], 1] ||
-        ua[%r[CoreMedia v([\d.]+)], 1] ||
+      ua[%r{(?:QuickTime)/([\d.]+)}, 1] ||
+        ua[/CoreMedia v([\d.]+)/, 1] ||
         "0.0"
     end
 
@@ -25,9 +25,7 @@ module Browser
       true
     end
 
-    private
-
-    def infer_name
+    private def infer_name
       (NAMES.find {|key, _| ua.include?(key) } || []).last
     end
   end
