@@ -8,7 +8,7 @@ module Browser
       end
 
       def version
-        ua[%r[AdobeAIR/([\d.]+)], 1]
+        ua[%r{AdobeAIR/([\d.]+)}, 1]
       end
 
       def name
