@@ -11,15 +11,15 @@ module Browser
     end
 
     def full_version
-      ua[%r[(?:Mobile MQQBrowser)/([\d.]+)]i, 1] ||
-        ua[%r[(?:QQBrowserLite)/([\d.]+)]i, 1] ||
-        ua[%r[(?:QQBrowser)/([\d.]+)]i, 1] ||
-        ua[%r[(?:QQ)/([\d.]+)]i, 1] ||
+      ua[%r{(?:Mobile MQQBrowser)/([\d.]+)}i, 1] ||
+        ua[%r{(?:QQBrowserLite)/([\d.]+)}i, 1] ||
+        ua[%r{(?:QQBrowser)/([\d.]+)}i, 1] ||
+        ua[%r{(?:QQ)/([\d.]+)}i, 1] ||
         "0.0"
     end
 
     def match?
-      ua =~ /QQ/i
+      ua =~ %r{QQ/|QQBrowser}i
     end
   end
 end
