@@ -1,10 +1,20 @@
 # frozen_string_literal: true
+
 require "rails"
 require "browser"
 
 class PagesController < ActionController::Base
   def home
-    render text: "#{browser.name}:#{browser.accept_language.first.full}"
+    render html: "#{browser.name}:#{browser.accept_language.first.full}"
+  end
+end
+
+class PotsController < ActionController::API
+  def index
+    render json: {
+      isBot: browser.bot?,
+      acceptLanguages: browser.accept_language.map(&:full)
+    }
   end
 end
 
@@ -14,10 +24,13 @@ class SampleApp < Rails::Application
   config.eager_load = true
   config.active_support.deprecation = :log
 
+  # Introduced by Rails 6.
+  config.hosts << "example.org" if config.respond_to?(:hosts)
+
   routes.append do
     default_headers = {"Content-Type" => "text/html"}
 
-    root to: -> (_env) { [200, default_headers, ["ROOT"]] }
+    root to: ->(_env) { [200, default_headers, ["ROOT"]] }
     get "upgrade", to: lambda {|env|
       browser = Rack::Request.new(env).params["browser"]
       [200, default_headers, ["UPGRADE: #{browser}"]]
@@ -28,6 +41,8 @@ class SampleApp < Rails::Application
     }
 
     get "/home", to: "pages#home"
+
+    get "/api/pages", to: "pots#index"
   end
 
   config.middleware.use Browser::Middleware do
