@@ -15,34 +15,6 @@ class BotsTest < Minitest::Test
     refute browser.bot?
   end
 
-  test "doesn't consider empty UA as bot" do
-    browser = Browser.new("")
-    refute browser.bot?
-  end
-
-  test "allows setting empty string as bots" do
-    Browser::Bot.detect_empty_ua!
-    browser = Browser.new("")
-
-    assert browser.bot?
-  end
-
-  test "allows setting nil as user agent for bots" do
-    browser = Browser.new(nil)
-    refute browser.bot?
-
-    Browser::Bot.detect_empty_ua!
-    browser = Browser.new(nil)
-    assert browser.bot?
-  end
-
-  test "doesn't detect mozilla as a bot when considering empty UA" do
-    Browser::Bot.detect_empty_ua!
-    browser = Browser.new("Mozilla")
-
-    refute browser.bot?
-  end
-
   test "returns bot name" do
     browser = Browser.new(Browser["GOOGLE_BOT"])
     assert_equal "Google Bot", browser.bot.name
@@ -51,13 +23,6 @@ class BotsTest < Minitest::Test
     assert_equal "Facebook Bot", browser.bot.name
   end
 
-  test "returns bot name (empty string ua detection enabled)" do
-    Browser::Bot.detect_empty_ua!
-    browser = Browser.new("")
-
-    assert_equal browser.bot.name, "Generic Bot"
-  end
-
   test "returns nil for non-bots" do
     browser = Browser.new(Browser["CHROME"])
     assert_nil browser.bot.name
@@ -84,7 +49,6 @@ class BotsTest < Minitest::Test
     refute browser.platform.windows10?
     refute browser.platform.windows_phone?
     refute browser.edge?
-    refute browser.modern?
     refute browser.device.mobile?
     refute browser.webkit?
     refute browser.chrome?
@@ -107,4 +71,41 @@ class BotsTest < Minitest::Test
 
     Browser::Bot.bots.delete("faraday")
   end
+
+  test "detects recognized bots using common libs" do
+    browser = Browser.new(Browser.bot_user_agents["LINKEDIN"])
+
+    assert browser.bot?
+    assert_equal "LinkedIn", browser.bot.name
+  end
+
+  test "tells why user agent is considered a bot" do
+    matcher = Browser::Bot.why?(Browser.bot_user_agents["LINKEDIN"])
+
+    assert_equal Browser::Bot::KnownBotsMatcher, matcher
+  end
+
+  test "adds custom bot matcher" do
+    Browser::Bot.matchers << ->(ua, _) { ua =~ /some-script/ }
+    browser = Browser.new("some-script")
+
+    assert browser.bot?
+    assert_equal "Generic Bot", browser.bot.name
+  end
+
+  %w[
+    content-fetcher
+    content-crawler
+    some-search-engine
+    monitoring-service
+    content-spider
+    some-bot
+  ].each do |ua|
+    test "detects user agents based on keywords (#{ua})" do
+      browser = Browser.new(ua)
+
+      assert browser.bot?
+      assert_equal Browser::Bot::KeywordMatcher, browser.bot.why?
+    end
+  end
 end
